#!/usr/bin/env bash
# ============================================================================ #
# This script will create a shortcut on applications menu for windows programs 
# installed with wine.
# Autor: Thiago silva
# Contact: thiagos.dasilva@gmail.com
# URL: https://github.com/thiggy01/wine-create-shortcut
# ============================================================================ #

# Check if an application argument was submited.
if [[ $(file --mime-type -b "$1") = application/* ]]; then

    # Get the full path, the name and directory name of submited application file.
    myFile=$(realpath "$1")
    myBaseName=$(basename "$myFile")
    myPath=$(dirname "$myFile")

    # Function to verify if required program is installed.
    VerInst () {
	if [ $? -eq 127 ]; then
	    echo "$1 package is not installed."
	    echo "Install it before running this script."
	    echo "Aborting."
	    exit 1
	fi
    }

    # Extract icon and convert it to several png files of diferent quality, 
    wrestool -x -t 14 "$myFile" > "/tmp/$myBaseName.ico" 2> /dev/null
    VerInst icoutils
    convert -alpha on "/tmp/$myBaseName.ico" "/tmp/$myBaseName.png" 2> /dev/null
    VerInst imagemagick
    # Select the best png image file.
    cp "$(ls -S -1 "/tmp/$myBaseName"*".png"  | head -n 1)" "$myFile.icon.png"

    # Get the app category and shortcut name inputs from the user.
    appCategory=$(zenity --title "wine-create-shortcut" --height=450 --list \
--radiolist --column " " --column "Categories" 0 AudioVideo 0 Audio 0 Video 0 \
Development 0 Education TRUE Game 0 Graphics 0 Network 0 Office 0 Settings 0 \
System 0 Utility  --text "Select a Category:" 2> /dev/null)
    VerInst zenity
    appName=$(zenity --title "wine-create-shortcut" --text "Enter a name for your \
shortcut" --entry)
    # Generate desktop entry specifications to be added to the application launcher.
    deskEntry="[Desktop Entry]"\\n"Exec=wine start /Unix \""$myFile"\""\\n"Name=\
$appName"\\n"Path=$myPath"\\n"Type=Application"\\n"Categories=Application;\
$category;"\\n"Icon="$myFile.icon.png""
    # Create a .desktop file and add desktop entries in it.
    echo -e $deskEntry >"$myFile".desktop
    # link the launcher  file to a shortcut on applications menu.
    ln -s "$myFile.desktop" "$HOME/.local/share/applications/$myBaseName.desktop"
    # Test if the app link was created sucessfully on applications menu 
    if [ $? -eq 0 ]; then
    	echo "Shortcut created sucessfuly on applications menu."
    fi

else 

# If no application was submited, show this message.
	echo Please, submit a windows application file. 
	echo Usage: ./wine-create-shortcut path/to/app.exe 
	echo

fi
